@@ -1,26 +1,14 @@
 /*
- * This file is part of the KDE Libraries
- * Copyright (C) 2007 Krzysztof Lichota (lichota@mimuw.edu.pl)
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE Libraries
+    SPDX-FileCopyrightText: 2007 Krzysztof Lichota <lichota@mimuw.edu.pl>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kswitchlanguagedialog_p.h"
 
+#include "debug.h"
+
 #include <QApplication>
 #include <QDialogButtonBox>
 #include <QDir>
@@ -30,7 +18,6 @@
 #include <QSettings>
 #include <QSharedPointer>
 #include <QStandardPaths>
-#include <QDebug>
 #include <private/qlocale_p.h>
 #include <QGridLayout>
 
@@ -156,7 +143,7 @@ KSwitchLanguageDialog::KSwitchLanguageDialog(QWidget *parent)
     : QDialog(parent),
       d(new KSwitchLanguageDialogPrivate(this))
 {
-    setWindowTitle(i18n("Switch Application Language"));
+    setWindowTitle(i18nc("@title:window", "Configure Language"));
 
     QVBoxLayout *topLayout = new QVBoxLayout;
     setLayout(topLayout);
@@ -188,8 +175,8 @@ KSwitchLanguageDialog::KSwitchLanguageDialog(QWidget *parent)
     QHBoxLayout *addButtonHorizontalLayout = new QHBoxLayout();
     topLayout->addLayout(addButtonHorizontalLayout);
 
-    QPushButton *addLangButton = new QPushButton(i18n("Add Fallback Language"), this);
-    addLangButton->setToolTip(i18n("Adds one more language which will be used if other translations do not contain a proper translation."));
+    QPushButton *addLangButton = new QPushButton(i18nc("@action:button", "Add Fallback Language"), this);
+    addLangButton->setToolTip(i18nc("@info:tooltip", "Adds one more language which will be used if other translations do not contain a proper translation."));
     connect(addLangButton, &QPushButton::clicked,
             this, &KSwitchLanguageDialog::slotAddLanguageButton);
     addButtonHorizontalLayout->addWidget(addLangButton);
@@ -229,19 +216,19 @@ void KSwitchLanguageDialog::removeButtonClicked()
 {
     QObject const *signalSender = sender();
     if (!signalSender) {
-        qCritical() << "KSwitchLanguageDialog::removeButtonClicked() called directly, not using signal" << endl;
+        qCCritical(DEBUG_KXMLGUI) << "KSwitchLanguageDialog::removeButtonClicked() called directly, not using signal";
         return;
     }
 
     QPushButton *removeButton = const_cast<QPushButton *>(::qobject_cast<const QPushButton *>(signalSender));
     if (!removeButton) {
-        qCritical() << "KSwitchLanguageDialog::removeButtonClicked() called from something else than QPushButton" << endl;
+        qCCritical(DEBUG_KXMLGUI) << "KSwitchLanguageDialog::removeButtonClicked() called from something else than QPushButton";
         return;
     }
 
     QMap<QPushButton *, LanguageRowData>::iterator it = d->languageRows.find(removeButton);
     if (it == d->languageRows.end()) {
-        qCritical() << "KSwitchLanguageDialog::removeButtonClicked called from unknown QPushButton" << endl;
+        qCCritical(DEBUG_KXMLGUI) << "KSwitchLanguageDialog::removeButtonClicked called from unknown QPushButton";
         return;
     }
 
@@ -274,8 +261,7 @@ void KSwitchLanguageDialog::slotOk()
 {
     QStringList languages;
 
-    for (int i = 0, count = d->languageButtons.count(); i < count; ++i) {
-        KLanguageButton *languageButton = d->languageButtons[i];
+    for (auto *languageButton : qAsConst(d->languageButtons)) {
         languages << languageButton->current();
     }
 
@@ -287,7 +273,7 @@ void KSwitchLanguageDialog::slotOk()
         KMessageBox::information(
             this,
             i18n("The language for this application has been changed. The change will take effect the next time the application is started."), //text
-            i18n("Application Language Changed"), //caption
+            i18nc("@title:window", "Application Language Changed"), //caption
             QStringLiteral("ApplicationLanguageChangedWarning") //dontShowAgainName
         );
     }
@@ -342,7 +328,7 @@ void KSwitchLanguageDialogPrivate::fillApplicationLanguages(KLanguageButton *but
     QSet<QString> insertedLanguges;
 
     const QList<QLocale> allLocales = QLocale::matchingLocales(QLocale::AnyLanguage, QLocale::AnyScript, QLocale::AnyCountry);
-    foreach(const QLocale &l, allLocales) {
+    for (const QLocale &l : allLocales) {
         if (l != cLocale) {
             QString languageCode = l.name();
             if (!insertedLanguges.contains(languageCode) && KLocalizedString::isApplicationTranslatedInto(languageCode)) {
@@ -371,8 +357,8 @@ QStringList KSwitchLanguageDialogPrivate::applicationLanguageList()
         languagesList = l.uiLanguages();
 
         // We get en-US here but we use en_US
-        for (int i = 0; i < languagesList.count(); ++i) {
-            languagesList[i].replace(QLatin1Char('-'), QLatin1Char('_'));
+        for (auto &language : languagesList) {
+            language.replace(QLatin1Char('-'), QLatin1Char('_'));
         }
     }
 
@@ -400,6 +386,7 @@ void KSwitchLanguageDialogPrivate::addLanguageButton(const QString &languageCode
     QString labelText = primaryLanguage ? i18n("Primary language:") : i18n("Fallback language:");
 
     KLanguageButton *languageButton = new KLanguageButton(p);
+    languageButton->showLanguageCodes(true);
 
     fillApplicationLanguages(languageButton);
 
@@ -412,15 +399,15 @@ void KSwitchLanguageDialogPrivate::addLanguageButton(const QString &languageCode
     QPushButton *removeButton = nullptr;
 
     if (!primaryLanguage) {
-        removeButton = new QPushButton(i18n("Remove"), p);
+        removeButton = new QPushButton(i18nc("@action:button", "Remove"), p);
 
         QObject::connect(removeButton, &QPushButton::clicked,
                          p, &KSwitchLanguageDialog::removeButtonClicked);
     }
 
     languageButton->setToolTip(primaryLanguage
-                               ? i18n("This is the main application language which will be used first, before any other languages.")
-                               : i18n("This is the language which will be used if any previous languages do not contain a proper translation."));
+                               ? i18nc("@info:tooltip", "This is the main application language which will be used first, before any other languages.")
+                               : i18nc("@info:tooltip", "This is the language which will be used if any previous languages do not contain a proper translation."));
 
     int numRows = languagesLayout->rowCount();
 
